# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text.textfield
from __future__ import annotations
from abc import abstractproperty
from ..dependent_text_field import DependentTextField as DependentTextField_fed90ded

class SetExpression(DependentTextField_fed90ded):
    """
    Service Class

    specifies service of an expression text field.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API SetExpression <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.SetExpression'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Content(self) -> str:
        """
        contains the textual content of the field.
        """
        ...

    @abstractproperty
    def CurrentPresentation(self) -> str:
        """
        contains the current content of the text field.
        
        This property is especially useful for import/export purposes.
        """
        ...

    @abstractproperty
    def Hint(self) -> str:
        """
        contains an informational text that is displayed at the user interface if it's an input field.
        """
        ...

    @abstractproperty
    def IsFixedLanguage(self) -> bool:
        """
        determines whether changes in language attributes at the position the text field is located also change the number format as appropriate for this language.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def IsInput(self) -> bool:
        """
        determines whether this field is an input field.
        """
        ...

    @abstractproperty
    def IsShowFormula(self) -> bool:
        """
        determines whether the content is displayed or evaluated.
        """
        ...

    @abstractproperty
    def IsVisible(self) -> bool:
        """
        determines whether the field is visible.
        """
        ...

    @abstractproperty
    def NumberFormat(self) -> int:
        """
        this is the number format for this field.
        """
        ...

    @abstractproperty
    def NumberingType(self) -> int:
        """
        specifies the type of the numbering as com.sun.star.style.NumberingType
        """
        ...

    @abstractproperty
    def SequenceValue(self) -> int:
        """
        contains the sequence value when this field is used as sequence field.
        """
        ...

    @abstractproperty
    def SubType(self) -> int:
        """
        determines the type of the variable as described in com.sun.star.text.SetVariableType
        """
        ...

    @abstractproperty
    def Value(self) -> float:
        """
        contains the numerical value of the field.
        """
        ...

    @abstractproperty
    def VariableName(self) -> str:
        """
        contains the name of the set expression field master this field is connected to.
        """
        ...


__all__ = ['SetExpression']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.graphic
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_graphic_renderer import XGraphicRenderer as XGraphicRenderer_aca0e33
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9

class GraphicRendererVCL(XPropertySet_bc180bfa, XGraphicRenderer_aca0e33):
    """
    Service Class

    Service that describes the necessary interfaces and properties to render a graphic container of XGraphic type.
    
    To render a XGraphic container, just create an instance of this service, set the appropriate properties and use the XGraphicRenderer interface to initiate the rendering process itself

    See Also:
        `API GraphicRendererVCL <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicRendererVCL.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.graphic'
    __ooo_full_ns__: str = 'com.sun.star.graphic.GraphicRendererVCL'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DestinationRect(self) -> Rectangle_84b109e9:
        """
        Specifies the destination rectangle, into which the graphic content is to be rendered onto the device.
        """
        ...

    @abstractproperty
    def Device(self) -> object:
        """
        Holds the device onto which the XGraphic container should be rendered.
        
        In case of using VCL Devices, this property should hold a com.sun.star.awt.XDevice interface
        """
        ...

    @abstractproperty
    def RenderData(self) -> object:
        """
        Additional properties for rendering, unspecified at the moment.
        """
        ...


__all__ = ['GraphicRendererVCL']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XInterceptorInfo(XInterface_8f010a43):
    """
    makes it possible to get information about a registered interceptor and is used by frame interceptor mechanism to perform interception.
    
    Frame can call right interceptor directly without calling all of registered ones. Use it as an additional interface to XDispatchProviderInterceptor. If any interceptor in list doesn't support this interface - these mechanism will be broken and normal list of master-slave interceptor objects will be used from top to the bottom.

    See Also:
        `API XInterceptorInfo <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XInterceptorInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XInterceptorInfo'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XInterceptorInfo'

    @abstractmethod
    def getInterceptedURLs(self) -> typing.Tuple[str, ...]:
        """
        returns the URL list for interception.
        
        Wildcards inside the URLs are allowed to register the interceptor for URLs too, which can have optional arguments (e.g. \"..#..\" or \"..?..\").
        """
        ...

__all__ = ['XInterceptorInfo']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .xui_element_factory import XUIElementFactory as XUIElementFactory_d0280c7e

class XUIElementFactoryRegistration(XInterface_8f010a43):
    """
    is used to query, register and deregister user interface element factories.
    
    A user interface element factory is registered for a set of three properties.
    
    A combination of these three property values can uniquely identify every user interface element within OpenOffice.
    
    Currently the following user interface element types are defined:
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUIElementFactoryRegistration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XUIElementFactoryRegistration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XUIElementFactoryRegistration'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XUIElementFactoryRegistration'

    @abstractmethod
    def deregisterFactory(self, aType: str, aName: str, ModuleIdentifier: str) -> None:
        """
        function to remove a previously defined user interface element factory.
        
        Using this function can be very dangerous as other implementation with OpenOffice may not be able to create their user interface element anymore.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def getFactory(self, ResourceURL: str, ModuleIdentifier: str) -> XUIElementFactory_d0280c7e:
        """
        function to retrieve a previously registered user interface element factory.
        """
        ...
    @abstractmethod
    def getRegisteredFactories(self) -> typing.Tuple[typing.Tuple[PropertyValue_c9610c73, ...], ...]:
        """
        function to retrieve a list of all registered user interface element factories
        
        The following properties are defined:
        """
        ...
    @abstractmethod
    def registerFactory(self, aType: str, aName: str, aModuleIdentifier: str, aFactoryImplementationName: str) -> None:
        """
        function to register a user interface element factory.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...

__all__ = ['XUIElementFactoryRegistration']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.frame.app_dispatch_provider import AppDispatchProvider as AppDispatchProvider
with suppress(ImportError):
    from ...dyn.frame.auto_recovery import AutoRecovery as AutoRecovery
with suppress(ImportError):
    from ...dyn.frame.bibliography import Bibliography as Bibliography
with suppress(ImportError):
    from ...dyn.frame.border_widths import BorderWidths as BorderWidths
with suppress(ImportError):
    from ...dyn.frame.command_group import CommandGroup as CommandGroup
with suppress(ImportError):
    from ...dyn.frame.command_group import CommandGroupEnum as CommandGroupEnum
with suppress(ImportError):
    from ...dyn.frame.components import Components as Components
with suppress(ImportError):
    from ...dyn.frame.content_handler import ContentHandler as ContentHandler
with suppress(ImportError):
    from ...dyn.frame.content_handler_factory import ContentHandlerFactory as ContentHandlerFactory
with suppress(ImportError):
    from ...dyn.frame.control_command import ControlCommand as ControlCommand
with suppress(ImportError):
    from ...dyn.frame.control_event import ControlEvent as ControlEvent
with suppress(ImportError):
    from ...dyn.frame.controller import Controller as Controller
with suppress(ImportError):
    from ...dyn.frame.desktop import Desktop as Desktop
with suppress(ImportError):
    from ...dyn.frame.desktop_task import DesktopTask as DesktopTask
with suppress(ImportError):
    from ...dyn.frame.desktop_tasks import DesktopTasks as DesktopTasks
with suppress(ImportError):
    from ...dyn.frame.dispatch_descriptor import DispatchDescriptor as DispatchDescriptor
with suppress(ImportError):
    from ...dyn.frame.dispatch_helper import DispatchHelper as DispatchHelper
with suppress(ImportError):
    from ...dyn.frame.dispatch_information import DispatchInformation as DispatchInformation
with suppress(ImportError):
    from ...dyn.frame.dispatch_provider import DispatchProvider as DispatchProvider
with suppress(ImportError):
    from ...dyn.frame.dispatch_recorder import DispatchRecorder as DispatchRecorder
with suppress(ImportError):
    from ...dyn.frame.dispatch_recorder_supplier import DispatchRecorderSupplier as DispatchRecorderSupplier
with suppress(ImportError):
    from ...dyn.frame.dispatch_result_event import DispatchResultEvent as DispatchResultEvent
with suppress(ImportError):
    from ...dyn.frame.dispatch_result_state import DispatchResultState as DispatchResultState
with suppress(ImportError):
    from ...dyn.frame.dispatch_result_state import DispatchResultStateEnum as DispatchResultStateEnum
with suppress(ImportError):
    from ...dyn.frame.dispatch_statement import DispatchStatement as DispatchStatement
with suppress(ImportError):
    from ...dyn.frame.document_templates import DocumentTemplates as DocumentTemplates
with suppress(ImportError):
    from ...dyn.frame.double_initialization_exception import DoubleInitializationException as DoubleInitializationException
with suppress(ImportError):
    from ...dyn.frame.feature_state_event import FeatureStateEvent as FeatureStateEvent
with suppress(ImportError):
    from ...dyn.frame.frame import Frame as Frame
with suppress(ImportError):
    from ...dyn.frame.frame_action import FrameAction as FrameAction
with suppress(ImportError):
    from ...dyn.frame.frame_action_event import FrameActionEvent as FrameActionEvent
with suppress(ImportError):
    from ...dyn.frame.frame_control import FrameControl as FrameControl
with suppress(ImportError):
    from ...dyn.frame.frame_loader import FrameLoader as FrameLoader
with suppress(ImportError):
    from ...dyn.frame.frame_loader_factory import FrameLoaderFactory as FrameLoaderFactory
with suppress(ImportError):
    from ...dyn.frame.frame_search_flag import FrameSearchFlag as FrameSearchFlag
with suppress(ImportError):
    from ...dyn.frame.frame_search_flag import FrameSearchFlagEnum as FrameSearchFlagEnum
with suppress(ImportError):
    from ...dyn.frame.frames_container import FramesContainer as FramesContainer
with suppress(ImportError):
    from ...dyn.frame.global_event_broadcaster import GlobalEventBroadcaster as GlobalEventBroadcaster
with suppress(ImportError):
    from ...dyn.frame.illegal_argument_io_exception import IllegalArgumentIOException as IllegalArgumentIOException
with suppress(ImportError):
    from ...dyn.frame.infobar_type import InfobarType as InfobarType
with suppress(ImportError):
    from ...dyn.frame.infobar_type import InfobarTypeEnum as InfobarTypeEnum
with suppress(ImportError):
    from ...dyn.frame.layout_manager import LayoutManager as LayoutManager
with suppress(ImportError):
    from ...dyn.frame.layout_manager_events import LayoutManagerEvents as LayoutManagerEvents
with suppress(ImportError):
    from ...dyn.frame.layout_manager_events import LayoutManagerEventsEnum as LayoutManagerEventsEnum
with suppress(ImportError):
    from ...dyn.frame.media_type_detection_helper import MediaTypeDetectionHelper as MediaTypeDetectionHelper
with suppress(ImportError):
    from ...dyn.frame.module_manager import ModuleManager as ModuleManager
with suppress(ImportError):
    from ...dyn.frame.office_frame_loader import OfficeFrameLoader as OfficeFrameLoader
with suppress(ImportError):
    from ...dyn.frame.popup_menu_controller import PopupMenuController as PopupMenuController
with suppress(ImportError):
    from ...dyn.frame.popup_menu_controller_factory import PopupMenuControllerFactory as PopupMenuControllerFactory
with suppress(ImportError):
    from ...dyn.frame.protocol_handler import ProtocolHandler as ProtocolHandler
with suppress(ImportError):
    from ...dyn.frame.session_listener import SessionListener as SessionListener
with suppress(ImportError):
    from ...dyn.frame.session_manager import SessionManager as SessionManager
with suppress(ImportError):
    from ...dyn.frame.settings import Settings as Settings
with suppress(ImportError):
    from ...dyn.frame.start_module import StartModule as StartModule
with suppress(ImportError):
    from ...dyn.frame.statusbar_controller import StatusbarController as StatusbarController
with suppress(ImportError):
    from ...dyn.frame.statusbar_controller_factory import StatusbarControllerFactory as StatusbarControllerFactory
with suppress(ImportError):
    from ...dyn.frame.synchronous_frame_loader import SynchronousFrameLoader as SynchronousFrameLoader
with suppress(ImportError):
    from ...dyn.frame.task import Task as Task
with suppress(ImportError):
    from ...dyn.frame.task_creator import TaskCreator as TaskCreator
with suppress(ImportError):
    from ...dyn.frame.template_access import TemplateAccess as TemplateAccess
with suppress(ImportError):
    from ...dyn.frame.termination_veto_exception import TerminationVetoException as TerminationVetoException
with suppress(ImportError):
    from ...dyn.frame.title_changed_event import TitleChangedEvent as TitleChangedEvent
with suppress(ImportError):
    from ...dyn.frame.toolbar_controller import ToolbarController as ToolbarController
with suppress(ImportError):
    from ...dyn.frame.toolbar_controller_factory import ToolbarControllerFactory as ToolbarControllerFactory
with suppress(ImportError):
    from ...dyn.frame.transient_documents_document_content_factory import TransientDocumentsDocumentContentFactory as TransientDocumentsDocumentContentFactory
with suppress(ImportError):
    from ...dyn.frame.ui_command_description import UICommandDescription as UICommandDescription
with suppress(ImportError):
    from ...dyn.frame.unknown_module_exception import UnknownModuleException as UnknownModuleException
with suppress(ImportError):
    from ...dyn.frame.untitled_numbers_const import UntitledNumbersConst as UntitledNumbersConst
with suppress(ImportError):
    from ...dyn.frame.untitled_numbers_const import UntitledNumbersConstEnum as UntitledNumbersConstEnum
with suppress(ImportError):
    from ...dyn.frame.window_arrange import WindowArrange as WindowArrange
with suppress(ImportError):
    from ...dyn.frame.window_arrange import WindowArrangeEnum as WindowArrangeEnum
with suppress(ImportError):
    from ...dyn.frame.x_app_dispatch_provider import XAppDispatchProvider as XAppDispatchProvider
with suppress(ImportError):
    from ...dyn.frame.x_border_resize_listener import XBorderResizeListener as XBorderResizeListener
with suppress(ImportError):
    from ...dyn.frame.x_browse_history_registry import XBrowseHistoryRegistry as XBrowseHistoryRegistry
with suppress(ImportError):
    from ...dyn.frame.x_component_loader import XComponentLoader as XComponentLoader
with suppress(ImportError):
    from ...dyn.frame.x_component_registry import XComponentRegistry as XComponentRegistry
with suppress(ImportError):
    from ...dyn.frame.x_config_manager import XConfigManager as XConfigManager
with suppress(ImportError):
    from ...dyn.frame.x_control_notification_listener import XControlNotificationListener as XControlNotificationListener
with suppress(ImportError):
    from ...dyn.frame.x_controller import XController as XController
with suppress(ImportError):
    from ...dyn.frame.x_controller2 import XController2 as XController2
with suppress(ImportError):
    from ...dyn.frame.x_controller_border import XControllerBorder as XControllerBorder
with suppress(ImportError):
    from ...dyn.frame.x_desktop import XDesktop as XDesktop
with suppress(ImportError):
    from ...dyn.frame.x_desktop2 import XDesktop2 as XDesktop2
with suppress(ImportError):
    from ...dyn.frame.x_desktop_task import XDesktopTask as XDesktopTask
with suppress(ImportError):
    from ...dyn.frame.x_dispatch import XDispatch as XDispatch
with suppress(ImportError):
    from ...dyn.frame.x_dispatch_helper import XDispatchHelper as XDispatchHelper
with suppress(ImportError):
    from ...dyn.frame.x_dispatch_information_provider import XDispatchInformationProvider as XDispatchInformationProvider
with suppress(ImportError):
    from ...dyn.frame.x_dispatch_provider import XDispatchProvider as XDispatchProvider
with suppress(ImportError):
    from ...dyn.frame.x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception
with suppress(ImportError):
    from ...dyn.frame.x_dispatch_provider_interceptor import XDispatchProviderInterceptor as XDispatchProviderInterceptor
with suppress(ImportError):
    from ...dyn.frame.x_dispatch_recorder import XDispatchRecorder as XDispatchRecorder
with suppress(ImportError):
    from ...dyn.frame.x_dispatch_recorder_supplier import XDispatchRecorderSupplier as XDispatchRecorderSupplier
with suppress(ImportError):
    from ...dyn.frame.x_dispatch_result_listener import XDispatchResultListener as XDispatchResultListener
with suppress(ImportError):
    from ...dyn.frame.x_document_templates import XDocumentTemplates as XDocumentTemplates
with suppress(ImportError):
    from ...dyn.frame.x_extended_filter_detection import XExtendedFilterDetection as XExtendedFilterDetection
with suppress(ImportError):
    from ...dyn.frame.x_filter_detect import XFilterDetect as XFilterDetect
with suppress(ImportError):
    from ...dyn.frame.x_frame import XFrame as XFrame
with suppress(ImportError):
    from ...dyn.frame.x_frame2 import XFrame2 as XFrame2
with suppress(ImportError):
    from ...dyn.frame.x_frame_action_listener import XFrameActionListener as XFrameActionListener
with suppress(ImportError):
    from ...dyn.frame.x_frame_loader import XFrameLoader as XFrameLoader
with suppress(ImportError):
    from ...dyn.frame.x_frame_loader_query import XFrameLoaderQuery as XFrameLoaderQuery
with suppress(ImportError):
    from ...dyn.frame.x_frame_set_model import XFrameSetModel as XFrameSetModel
with suppress(ImportError):
    from ...dyn.frame.x_frames import XFrames as XFrames
with suppress(ImportError):
    from ...dyn.frame.x_frames_supplier import XFramesSupplier as XFramesSupplier
with suppress(ImportError):
    from ...dyn.frame.x_global_event_broadcaster import XGlobalEventBroadcaster as XGlobalEventBroadcaster
with suppress(ImportError):
    from ...dyn.frame.x_infobar_provider import XInfobarProvider as XInfobarProvider
with suppress(ImportError):
    from ...dyn.frame.x_interceptor_info import XInterceptorInfo as XInterceptorInfo
with suppress(ImportError):
    from ...dyn.frame.x_layout_manager import XLayoutManager as XLayoutManager
with suppress(ImportError):
    from ...dyn.frame.x_layout_manager2 import XLayoutManager2 as XLayoutManager2
with suppress(ImportError):
    from ...dyn.frame.x_layout_manager_event_broadcaster import XLayoutManagerEventBroadcaster as XLayoutManagerEventBroadcaster
with suppress(ImportError):
    from ...dyn.frame.x_layout_manager_listener import XLayoutManagerListener as XLayoutManagerListener
with suppress(ImportError):
    from ...dyn.frame.x_load_event_listener import XLoadEventListener as XLoadEventListener
with suppress(ImportError):
    from ...dyn.frame.x_loadable import XLoadable as XLoadable
with suppress(ImportError):
    from ...dyn.frame.x_loader_factory import XLoaderFactory as XLoaderFactory
with suppress(ImportError):
    from ...dyn.frame.x_menu_bar_acceptor import XMenuBarAcceptor as XMenuBarAcceptor
with suppress(ImportError):
    from ...dyn.frame.x_menu_bar_merging_acceptor import XMenuBarMergingAcceptor as XMenuBarMergingAcceptor
with suppress(ImportError):
    from ...dyn.frame.x_model import XModel as XModel
with suppress(ImportError):
    from ...dyn.frame.x_model2 import XModel2 as XModel2
with suppress(ImportError):
    from ...dyn.frame.x_model3 import XModel3 as XModel3
with suppress(ImportError):
    from ...dyn.frame.x_module import XModule as XModule
with suppress(ImportError):
    from ...dyn.frame.x_module_manager import XModuleManager as XModuleManager
with suppress(ImportError):
    from ...dyn.frame.x_module_manager2 import XModuleManager2 as XModuleManager2
with suppress(ImportError):
    from ...dyn.frame.x_notifying_dispatch import XNotifyingDispatch as XNotifyingDispatch
with suppress(ImportError):
    from ...dyn.frame.x_popup_menu_controller import XPopupMenuController as XPopupMenuController
with suppress(ImportError):
    from ...dyn.frame.x_recordable_dispatch import XRecordableDispatch as XRecordableDispatch
with suppress(ImportError):
    from ...dyn.frame.x_session_manager_client import XSessionManagerClient as XSessionManagerClient
with suppress(ImportError):
    from ...dyn.frame.x_session_manager_listener import XSessionManagerListener as XSessionManagerListener
with suppress(ImportError):
    from ...dyn.frame.x_session_manager_listener2 import XSessionManagerListener2 as XSessionManagerListener2
with suppress(ImportError):
    from ...dyn.frame.x_status_listener import XStatusListener as XStatusListener
with suppress(ImportError):
    from ...dyn.frame.x_statusbar_controller import XStatusbarController as XStatusbarController
with suppress(ImportError):
    from ...dyn.frame.x_storable import XStorable as XStorable
with suppress(ImportError):
    from ...dyn.frame.x_storable2 import XStorable2 as XStorable2
with suppress(ImportError):
    from ...dyn.frame.x_sub_toolbar_controller import XSubToolbarController as XSubToolbarController
with suppress(ImportError):
    from ...dyn.frame.x_synchronous_dispatch import XSynchronousDispatch as XSynchronousDispatch
with suppress(ImportError):
    from ...dyn.frame.x_synchronous_frame_loader import XSynchronousFrameLoader as XSynchronousFrameLoader
with suppress(ImportError):
    from ...dyn.frame.x_task import XTask as XTask
with suppress(ImportError):
    from ...dyn.frame.x_tasks_supplier import XTasksSupplier as XTasksSupplier
with suppress(ImportError):
    from ...dyn.frame.x_terminate_listener import XTerminateListener as XTerminateListener
with suppress(ImportError):
    from ...dyn.frame.x_terminate_listener2 import XTerminateListener2 as XTerminateListener2
with suppress(ImportError):
    from ...dyn.frame.x_title import XTitle as XTitle
with suppress(ImportError):
    from ...dyn.frame.x_title_change_broadcaster import XTitleChangeBroadcaster as XTitleChangeBroadcaster
with suppress(ImportError):
    from ...dyn.frame.x_title_change_listener import XTitleChangeListener as XTitleChangeListener
with suppress(ImportError):
    from ...dyn.frame.x_toolbar_controller import XToolbarController as XToolbarController
with suppress(ImportError):
    from ...dyn.frame.x_toolbar_controller_listener import XToolbarControllerListener as XToolbarControllerListener
with suppress(ImportError):
    from ...dyn.frame.x_transient_documents_document_content_factory import XTransientDocumentsDocumentContentFactory as XTransientDocumentsDocumentContentFactory
with suppress(ImportError):
    from ...dyn.frame.x_transient_documents_document_content_identifier_factory import XTransientDocumentsDocumentContentIdentifierFactory as XTransientDocumentsDocumentContentIdentifierFactory
with suppress(ImportError):
    from ...dyn.frame.xui_controller_factory import XUIControllerFactory as XUIControllerFactory
with suppress(ImportError):
    from ...dyn.frame.xui_controller_registration import XUIControllerRegistration as XUIControllerRegistration
with suppress(ImportError):
    from ...dyn.frame.x_untitled_numbers import XUntitledNumbers as XUntitledNumbers
with suppress(ImportError):
    from ...dyn.frame.x_url_list import XUrlList as XUrlList
with suppress(ImportError):
    from ...dyn.frame.x_window_arranger import XWindowArranger as XWindowArranger
with suppress(ImportError):
    from ...dyn.frame.the_auto_recovery import theAutoRecovery as theAutoRecovery
with suppress(ImportError):
    from ...dyn.frame.the_desktop import theDesktop as theDesktop
with suppress(ImportError):
    from ...dyn.frame.the_global_event_broadcaster import theGlobalEventBroadcaster as theGlobalEventBroadcaster
with suppress(ImportError):
    from ...dyn.frame.the_popup_menu_controller_factory import thePopupMenuControllerFactory as thePopupMenuControllerFactory
with suppress(ImportError):
    from ...dyn.frame.the_statusbar_controller_factory import theStatusbarControllerFactory as theStatusbarControllerFactory
with suppress(ImportError):
    from ...dyn.frame.the_toolbar_controller_factory import theToolbarControllerFactory as theToolbarControllerFactory
with suppress(ImportError):
    from ...dyn.frame.the_ui_command_description import theUICommandDescription as theUICommandDescription



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb


class RowChangeAction(object):
    """
    Const Class

    determines the type of change which is going to be performed.

    See Also:
        `API RowChangeAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1RowChangeAction.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.RowChangeAction'
    __ooo_type_name__: str = 'const'

    INSERT = 1
    """
    indicates that an insert will be performed.
    """
    UPDATE = 2
    """
    indicates that an update will be performed.
    """
    DELETE = 3
    """
    indicates that a delete will be performed.
    """

__all__ = ['RowChangeAction']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.script.provider.language_script_provider import LanguageScriptProvider as LanguageScriptProvider
from ....lo.script.provider.master_script_provider import MasterScriptProvider as MasterScriptProvider
from ....lo.script.provider.master_script_provider_factory import MasterScriptProviderFactory as MasterScriptProviderFactory
from ....lo.script.provider.script_error_raised_exception import ScriptErrorRaisedException as ScriptErrorRaisedException
from ....lo.script.provider.script_exception_raised_exception import ScriptExceptionRaisedException as ScriptExceptionRaisedException
from ....lo.script.provider.script_framework_error_exception import ScriptFrameworkErrorException as ScriptFrameworkErrorException
from ....lo.script.provider.script_framework_error_type import ScriptFrameworkErrorType as ScriptFrameworkErrorType
from ....lo.script.provider.script_provider import ScriptProvider as ScriptProvider
from ....lo.script.provider.script_provider_for_basic import ScriptProviderForBasic as ScriptProviderForBasic
from ....lo.script.provider.script_provider_for_bean_shell import ScriptProviderForBeanShell as ScriptProviderForBeanShell
from ....lo.script.provider.script_provider_for_java import ScriptProviderForJava as ScriptProviderForJava
from ....lo.script.provider.script_provider_for_java_script import ScriptProviderForJavaScript as ScriptProviderForJavaScript
from ....lo.script.provider.script_uri_helper import ScriptURIHelper as ScriptURIHelper
from ....lo.script.provider.x_script import XScript as XScript
from ....lo.script.provider.x_script_context import XScriptContext as XScriptContext
from ....lo.script.provider.x_script_provider import XScriptProvider as XScriptProvider
from ....lo.script.provider.x_script_provider_factory import XScriptProviderFactory as XScriptProviderFactory
from ....lo.script.provider.x_script_provider_supplier import XScriptProviderSupplier as XScriptProviderSupplier
from ....lo.script.provider.x_script_uri_helper import XScriptURIHelper as XScriptURIHelper
from ....lo.script.provider.the_master_script_provider_factory import theMasterScriptProviderFactory as theMasterScriptProviderFactory



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .list_event import ListEvent as ListEvent_83fa09e0

class XDynamicResultSetListener(XEventListener_c7230c4a):
    """
    used to receive notifications from an XDynamicResultSet.

    See Also:
        `API XDynamicResultSetListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XDynamicResultSetListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XDynamicResultSetListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XDynamicResultSetListener'

    @abstractmethod
    def notify(self, Changes: ListEvent_83fa09e0) -> None:
        """
        A method used to propagate changes of a result set.
        
        In the first notify-call the listener gets two(!) com.sun.star.sdbc.XResultSets and has to hold them. The com.sun.star.sdbc.XResultSets are implementations of the service ContentResultSet.
        
        The notified new com.sun.star.sdbc.XResultSet will stay valid after returning from this method. The old one will become invalid after returning.
        
        While in notify-call the listener is allowed to read from old and new result set, except in the first call, where only the new result set is valid.
        
        The Listener is allowed to stay (block) this call, until he really wants to use the new result set. The only situation, where the listener has to return immediately is while he disposes his broadcaster or while he is removing himself as listener (otherwise you deadlock)!!!
        """
        ...

__all__ = ['XDynamicResultSetListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from .x_cipher_context_supplier import XCipherContextSupplier as XCipherContextSupplier_9fd31214
from .x_digest_context_supplier import XDigestContextSupplier as XDigestContextSupplier_a0151219
if typing.TYPE_CHECKING:
    from .nss_profile import NSSProfile as NSSProfile_e1f00ced

class XNSSInitializer(XCipherContextSupplier_9fd31214, XDigestContextSupplier_a0151219):
    """
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XNSSInitializer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XNSSInitializer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.XNSSInitializer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.XNSSInitializer'

    @abstractmethod
    def getNSSProfiles(self) -> typing.Tuple[NSSProfile_e1f00ced, ...]:
        """
        get the current profile list
        
        **since**
        
            LibreOffice 7.1
        """
        ...
    @abstractproperty
    def IsNSSinitialized(self) -> bool:
        """
        the state of the NSS initialization
        
        This attribute returns true, if the NSS library is initialized.
        
        **since**
        
            LibreOffice 7.1
        """
        ...

    @abstractproperty
    def NSSPath(self) -> str:
        """
        the current path to the NSS databases
        
        This attribute returns the current setting, based on the user selection or automatic detection. This value can change until someone uses NSS crypto functions, because just then LibreOffice initializes the NSS library and the value stays fixed until LibreOffice is restarted!
        
        **since**
        
            LibreOffice 7.1
        """
        ...


__all__ = ['XNSSInitializer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08

class DataPilotSourceMember(XPropertySet_bc180bfa, XNamed_a6520b08):
    """
    Service Class

    represents a member in a data pilot source level.
    
    Members are the data items that will appear in a data pilot table as row headers and column headers of the data range (if used in row or column dimensions), or to calculate the values of the data range (if used in data dimensions).
    
    **since**
    
        OOo 2.4

    See Also:
        `API DataPilotSourceMember <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceMember.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotSourceMember'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsVisible(self) -> bool:
        """
        specifies whether the member is visible.
        """
        ...

    @abstractproperty
    def Position(self) -> bool:
        """
        specifies the member's position in its hierarchy level if sorting is manual.
        
        **since**
        
            OOo 2.4
        """
        ...

    @abstractproperty
    def ShowDetails(self) -> bool:
        """
        specifies whether details for the member are shown.
        """
        ...


__all__ = ['DataPilotSourceMember']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.style
from __future__ import annotations
import typing
from abc import abstractmethod
from ..beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet_fd880e05
from ..beans.x_multi_property_states import XMultiPropertyStates as XMultiPropertyStates_2a3e0f4d
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6

class XAutoStyle(XMultiPropertySet_fd880e05, XMultiPropertyStates_2a3e0f4d):
    """
    This interface allows access to a single automatic style.

    See Also:
        `API XAutoStyle <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1style_1_1XAutoStyle.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.XAutoStyle'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.style.XAutoStyle'

    @abstractmethod
    def getProperties(self) -> PropertyValues_d6470ce6:
        """
        returns a sequence of all properties that are set in the style
        """
        ...

__all__ = ['XAutoStyle']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.graphic
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_stream import XStream as XStream_678908a4

class MediaProperties(ABC):
    """
    Service Class

    This service describes the properties that are used when using the XGraphicProvider interface methods.

    See Also:
        `API MediaProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1graphic_1_1MediaProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.graphic'
    __ooo_full_ns__: str = 'com.sun.star.graphic.MediaProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def FilterData(self) -> PropertyValues_d6470ce6:
        """
        Additional properties that will be passed to the appropriate filter module.
        """
        ...

    @abstractproperty
    def InputStream(self) -> XInputStream_98d40ab4:
        """
        This property is only used for loading graphics or querying graphic descriptors.
        
        A InputStream can be used instead of the URL property
        """
        ...

    @abstractproperty
    def MimeType(self) -> str:
        """
        This property is only used for storing graphics and describes the format into which the graphic is to be converted.
        
        At the moment, the following mime types are supported for storing graphics:
        """
        ...

    @abstractproperty
    def OutputStream(self) -> XStream_678908a4:
        """
        This property is only used for storing graphics.
        
        A OutputStream can be used instead of the URL property
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        Property that describes the location of the source or target of the graphic as URL.
        
        A URL can be used instead of the InputStream or OutputStream property
        
        In addition to the normal protocols like file:// or http:// you can use private URLs as follows to get access to graphics lying inside the graphicrepository system within an Office context:
        
        Note: As of LibreOffice 6.1 GraphicObject scheme URLs are not supported anymore. For example:
        """
        ...


__all__ = ['MediaProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.bridge
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..uno.uik import Uik as Uik_4fac0783

class XBridgeSupplier(XInterface_8f010a43):
    """
    defines the interface for creating bridges to other object models.
    
    Because bridges sometimes can not be generated in an address space, the implementation needs to check the address space of the caller by comparing the machine and process ID against its own. These IDs are provided by the UNO runtime.
    
    All objects, whether they are part of the UNO object model or not, are carried in an any. The representation of this object is heavily model-dependent and has to be specified in the following list:
    
    Any implementation can supply its own bridges to other object models by implementing this interface and returning the bridge when the method is called with itself as the first parameter.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XBridgeSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1bridge_1_1XBridgeSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.bridge'
    __ooo_full_ns__: str = 'com.sun.star.bridge.XBridgeSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.bridge.XBridgeSupplier'

    @abstractmethod
    def createBridge(self, modelDepObject: object, MachineId: Uik_4fac0783, ProcessId: int, sourceModelType: int, destModelType: int) -> object:
        """
        creates a bridge to provide an object of one object model with another.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XBridgeSupplier']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XModifyListener(XEventListener_c7230c4a):
    """
    makes it possible to receive events when a model object changes.

    See Also:
        `API XModifyListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XModifyListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XModifyListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XModifyListener'

    @abstractmethod
    def modified(self, aEvent: EventObject_a3d70b03) -> None:
        """
        is called when something changes in the object.
        
        Due to such an event, it may be necessary to update views or controllers.
        
        The source of the event may be the content of the object to which the listener is registered.
        """
        ...

__all__ = ['XModifyListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from abc import abstractmethod, ABC

class XLockable(ABC):
    """
    allows locking a component
    
    lock and unlock calls can be nested. However, they must be in pairs. As long as there has been one more call to lock than to unlock, the component is considered locked, which is reflected by isLocked() returning TRUE.

    See Also:
        `API XLockable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XLockable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XLockable'

    @abstractmethod
    def isLocked(self) -> bool:
        """
        determines whether the component is currently locked.
        """
        ...
    @abstractmethod
    def lock(self) -> None:
        """
        locks the component
        """
        ...
    @abstractmethod
    def unlock(self) -> None:
        """
        unlocks the component

        Raises:
            NotLockedException: ``NotLockedException``
        """
        ...

__all__ = ['XLockable']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2.data
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...awt.x_request_callback import XRequestCallback as XRequestCallback_d4ac0ca2
    from ...beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_data_provider import XDataProvider as XDataProvider_122f0e31
    from .x_data_source import XDataSource as XDataSource_f6340d57
    from .x_range_highlighter import XRangeHighlighter as XRangeHighlighter_4e810fc8
    from ...util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class XDataReceiver(XInterface_8f010a43):
    """
    
    **since**
    
        LibreOffice 5.4

    See Also:
        `API XDataReceiver <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataReceiver.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2.data'
    __ooo_full_ns__: str = 'com.sun.star.chart2.data.XDataReceiver'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.data.XDataReceiver'

    @abstractmethod
    def attachDataProvider(self, xProvider: XDataProvider_122f0e31) -> None:
        """
        attaches a component that provides data for the document.
        
        The previously set data provider will be released.
        """
        ...
    @abstractmethod
    def attachNumberFormatsSupplier(self, xSupplier: XNumberFormatsSupplier_3afb0fb7) -> None:
        """
        attaches an XNumberFormatsSupplier to this XDataReceiver.
        
        The given number formats will be used for display purposes.
        """
        ...
    @abstractmethod
    def getPopupRequest(self) -> XRequestCallback_d4ac0ca2:
        """
        A callback object to execute a foreign popup menu window.
        
        **since**
        
            LibreOffice 5.4
        """
        ...
    @abstractmethod
    def getRangeHighlighter(self) -> XRangeHighlighter_4e810fc8:
        """
        Returns a component at which a view representing the data of the attached data provider may listen for highlighting the data ranges used by the currently selected objects in the data receiver component.
        
        This is typically used by a spreadsheet to highlight the ranges used by the currently selected object in a chart.
        
        The range highlighter is optional, i.e., this method may return an empty object.
        """
        ...
    @abstractmethod
    def getUsedData(self) -> XDataSource_f6340d57:
        """
        Returns the data requested by the most recently attached data provider, that is still used.
        """
        ...
    @abstractmethod
    def getUsedRangeRepresentations(self) -> typing.Tuple[str, ...]:
        """
        returns a list of all range strings for which data has been requested by the most recently attached data provider, and which is still used.
        
        This list may be used by the data provider to swap charts out of memory, but still get informed by changes of ranges while the chart is not loaded.
        """
        ...
    @abstractmethod
    def setArguments(self, aArguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XDataReceiver']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..awt.point import Point as Point_5fb2085e
from ..awt.size import Size as Size_576707ef
from ..drawing.bitmap_mode import BitmapMode as BitmapMode_bced0bd6
from ..drawing.rectangle_point import RectanglePoint as RectanglePoint_f0ff0d93


class FillBitmap(object):
    """
    Struct Class

    This structure contains all properties of a bitmap when used as FillStyle.

    See Also:
        `API FillBitmap <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1FillBitmap.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.FillBitmap'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart2.FillBitmap'
    """Literal Constant ``com.sun.star.chart2.FillBitmap``"""

    def __init__(self, aURL: typing.Optional[str] = '', aOffset: typing.Optional[Point_5fb2085e] = UNO_NONE, aPositionOffset: typing.Optional[Point_5fb2085e] = UNO_NONE, aRectanglePoint: typing.Optional[RectanglePoint_f0ff0d93] = RectanglePoint_f0ff0d93.LEFT_TOP, bLogicalSize: typing.Optional[bool] = False, aSize: typing.Optional[Size_576707ef] = UNO_NONE, aBitmapMode: typing.Optional[BitmapMode_bced0bd6] = BitmapMode_bced0bd6.REPEAT) -> None:
        """
        Constructor

        Arguments:
            aURL (str, optional): aURL value.
            aOffset (Point, optional): aOffset value.
            aPositionOffset (Point, optional): aPositionOffset value.
            aRectanglePoint (RectanglePoint, optional): aRectanglePoint value.
            bLogicalSize (bool, optional): bLogicalSize value.
            aSize (Size, optional): aSize value.
            aBitmapMode (BitmapMode, optional): aBitmapMode value.
        """
        super().__init__()

        if isinstance(aURL, FillBitmap):
            oth: FillBitmap = aURL
            self.aURL = oth.aURL
            self.aOffset = oth.aOffset
            self.aPositionOffset = oth.aPositionOffset
            self.aRectanglePoint = oth.aRectanglePoint
            self.bLogicalSize = oth.bLogicalSize
            self.aSize = oth.aSize
            self.aBitmapMode = oth.aBitmapMode
            return

        kargs = {
            "aURL": aURL,
            "aOffset": aOffset,
            "aPositionOffset": aPositionOffset,
            "aRectanglePoint": aRectanglePoint,
            "bLogicalSize": bLogicalSize,
            "aSize": aSize,
            "aBitmapMode": aBitmapMode,
        }
        if kargs["aOffset"] is UNO_NONE:
            kargs["aOffset"] = None
        if kargs["aPositionOffset"] is UNO_NONE:
            kargs["aPositionOffset"] = None
        if kargs["aSize"] is UNO_NONE:
            kargs["aSize"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._a_url = kwargs["aURL"]
        self._a_offset = kwargs["aOffset"]
        self._a_position_offset = kwargs["aPositionOffset"]
        self._a_rectangle_point = kwargs["aRectanglePoint"]
        self._b_logical_size = kwargs["bLogicalSize"]
        self._a_size = kwargs["aSize"]
        self._a_bitmap_mode = kwargs["aBitmapMode"]


    @property
    def aURL(self) -> str:
        """
        a URL to the bitmap used.
        
        This may be an internal URL of the graphics manager.
        """
        return self._a_url

    @aURL.setter
    def aURL(self, value: str) -> None:
        self._a_url = value

    @property
    def aOffset(self) -> Point_5fb2085e:
        """
        This is the horizontal and vertical offset where the tile starts.
        
        It is given in percent in relation to the width of the bitmap.
        """
        return self._a_offset

    @aOffset.setter
    def aOffset(self, value: Point_5fb2085e) -> None:
        self._a_offset = value

    @property
    def aPositionOffset(self) -> Point_5fb2085e:
        """
        Every second line (X) / row (Y) of tiles is moved the given percent of the width of the bitmap.
        """
        return self._a_position_offset

    @aPositionOffset.setter
    def aPositionOffset(self, value: Point_5fb2085e) -> None:
        self._a_position_offset = value

    @property
    def aRectanglePoint(self) -> RectanglePoint_f0ff0d93:
        """
        The RectanglePoint specifies the position inside of the bitmap to use as the top left position for rendering.
        """
        return self._a_rectangle_point

    @aRectanglePoint.setter
    def aRectanglePoint(self, value: RectanglePoint_f0ff0d93) -> None:
        self._a_rectangle_point = value

    @property
    def bLogicalSize(self) -> bool:
        """
        specifies if the size is given in percentage or as an absolute value.
        
        If this is TRUE, the properties SizeX and SizeY contain the size of the tile in percent of the size of the original bitmap. If this is FALSE, the size of the tile is specified with 1/100th mm.
        """
        return self._b_logical_size

    @bLogicalSize.setter
    def bLogicalSize(self, value: bool) -> None:
        self._b_logical_size = value

    @property
    def aSize(self) -> Size_576707ef:
        """
        This is the size of the tile for filling.
        
        Depending on the property LogicalSize, this is either relative or absolute.
        """
        return self._a_size

    @aSize.setter
    def aSize(self, value: Size_576707ef) -> None:
        self._a_size = value

    @property
    def aBitmapMode(self) -> BitmapMode_bced0bd6:
        """
        this enum selects how an area is filled with a single bitmap.
        
        It may be repeated, stretched or displayed with blank space around it.
        """
        return self._a_bitmap_mode

    @aBitmapMode.setter
    def aBitmapMode(self, value: BitmapMode_bced0bd6) -> None:
        self._a_bitmap_mode = value


__all__ = ['FillBitmap']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.media
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XPlayerListener(XEventListener_c7230c4a):
    """
    Interface to be implemented by a Player listener.
    
    The XPlayerListener interface must be implemented by the clients of the Player service which need to be informed about events while the Player service is displayed.
    
    **since**
    
        LibreOffice 7.4

    See Also:
        `API XPlayerListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1media_1_1XPlayerListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.media'
    __ooo_full_ns__: str = 'com.sun.star.media.XPlayerListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.media.XPlayerListener'

    @abstractmethod
    def preferredPlayerWindowSizeAvailable(self, e: EventObject_a3d70b03) -> None:
        """
        A client receives this event when the preferred player size of an XPlayer is available to be queried.
        """
        ...

__all__ = ['XPlayerListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from .alias_programmatic_pair import AliasProgrammaticPair as AliasProgrammaticPair_2a930f22

class XLocalizedAliases(XInterface_8f010a43):
    """
    is the interface for binding programmatic names to aliases.
    
    Aliases can be provided in several locales for the same programmatic name.

    See Also:
        `API XLocalizedAliases <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XLocalizedAliases'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XLocalizedAliases'

    @abstractmethod
    def bindAlias(self, programmaticName: str, locale: Locale_70d308fa, alias: str) -> None:
        """
        registers an alias for a programmatic name.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def listAliases(self, locale: Locale_70d308fa) -> typing.Tuple[AliasProgrammaticPair_2a930f22, ...]:
        """
        retrieves a list of all registered aliases for a certain language.
        """
        ...
    @abstractmethod
    def lookupAlias(self, locale: Locale_70d308fa, Alias: str) -> str:
        """
        retrieves a registered programmatic name identified by an alias.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def lookupProgrammatic(self, locale: Locale_70d308fa, programmatic: str) -> str:
        """
        retrieves a given alias for a programmatic name.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def rebindAliases(self, currentProgrammatic: str, newProgrammatic: str) -> None:
        """
        rebinds all aliases registered to a given URL to a new one.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def renameAlias(self, locale: Locale_70d308fa, oldName: str, aNewName: str) -> None:
        """
        renames an alias for a programmatic name.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def unbindAlias(self, locale: Locale_70d308fa, alias: str) -> None:
        """
        revokes an alias for a programmatic name.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def unbindAliases(self, programmaticName: str) -> None:
        """
        removes all aliases for a programmatic name.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XLocalizedAliases']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from ..container.x_named import XNamed as XNamed_a6520b08
from .x_frame_loader import XFrameLoader as XFrameLoader_ba3a0bad
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca

class FrameLoader(XNamed_a6520b08, XFrameLoader_ba3a0bad, XInitialization_d46c0cca):
    """
    Service Class

    derivations of this abstract service are used to load components into Frames of the environment
    
    Concrete implementations of this service register, for example, for file name extensions or MIME types to load appropriate components. The components loaded are at least Controller. Instead of SynchronousFrameLoader this one use asynchronous processes to load the component.

    See Also:
        `API FrameLoader <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1FrameLoader.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.FrameLoader'
    __ooo_type_name__: str = 'service'


__all__ = ['FrameLoader']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XNumberText(ABC):
    """
    This interface allows to spell out numbers and money amounts.
    
    The current set of supported languages is:
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API XNumberText <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XNumberText.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XNumberText'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XNumberText'

    @abstractmethod
    def getAvailableLanguages(self) -> typing.Tuple[Locale_70d308fa, ...]:
        """
        returns a list of all supported languages.
        """
        ...
    @abstractmethod
    def getNumberText(self, aText: str, aLocale: Locale_70d308fa) -> str:
        """
        spell out numbers and money amounts
        
        Please note that text argument can contain prefixes separated by space, for example \"ordinal\" for ordinal numbers, \"ordinal-number\" for ordinal indicators and ISO 4217 currency codes.
        
        Language modules list the supported prefixes by the input text \"help\".

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XNumberText']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_resource_factory import XResourceFactory as XResourceFactory_b3561268
if typing.TYPE_CHECKING:
    from ...frame.x_controller import XController as XController_b00e0b8f

class BasicToolBarFactory(XResourceFactory_b3561268):
    """
    Service Class

    The BasicToolBarFactory is a resource factory that provides (some of) the tool bars used by the Draw and Impress applications.
    
    The factory recognizes the following URLs:
    
    This short list marks the implementation of this service clearly as being in transition.
    
    This factory is typically created indirectly by registering it in the configuration and have the XModuleController create it on demand.

    See Also:
        `API BasicToolBarFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1BasicToolBarFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.BasicToolBarFactory'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, xController: XController_b00e0b8f) -> None:
        """
        Give the controller to new instances so that they have access to the drawing framework controllers.
        """
        ...

__all__ = ['BasicToolBarFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_common_embed_persist import XCommonEmbedPersist as XCommonEmbedPersist_16930e8d
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_storage import XStorage as XStorage_8e460a32

class XEmbedPersist(XCommonEmbedPersist_16930e8d):
    """
    specifies an implementation for embedded object persistence.
    
    The idea is that any usable embedded object should be initialized with an entry in the parent storage that will be used as persistent representation.

    See Also:
        `API XEmbedPersist <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XEmbedPersist.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XEmbedPersist'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XEmbedPersist'

    @abstractmethod
    def getEntryName(self) -> str:
        """
        allows to retrieve the current object entry name.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def hasEntry(self) -> bool:
        """
        allows to detect if the object has entry.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def saveCompleted(self, bUseNew: bool) -> None:
        """
        specifies whether the object should use an old storage or a new one after \"save as\" operation.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def setPersistentEntry(self, xStorage: XStorage_8e460a32, sEntName: str, nEntryConnectionMode: int, aMediaArgs: typing.Tuple[PropertyValue_c9610c73, ...], aObjectArgs: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        provides object with a parent storage and a name for object's entry.
        
        An entry with the specified name should be created/opened inside provided storage. It can be a storage or a stream. For example, OOo API will refer to OLE storages only by streams, but the object implementation will use storage based on this stream.
        
        Factory does this call to initialize the embedded object. The linked object can be initialized by factory in different way ( internally ).
        
        It is also possible to switch object persistent representation through this call. Actually this is the way, this call can be used by user ( since initialization is done by factory ).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def storeAsEntry(self, xStorage: XStorage_8e460a32, sEntName: str, aMediaArgs: typing.Tuple[PropertyValue_c9610c73, ...], aObjectArgs: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        lets the object store itself to an entry in destination storage and prepare to use the new entry for own persistence.
        
        The object should be stored to the new entry, after that the entry should be remembered by the object. After the storing process is finished the XEmbedPersist.saveCompleted() method can be used to specify whether the object should use the new entry or the old one. The object persistence can not be used until XEmbedPersist.saveCompleted() is called. So this state can be treated as \"HandsOff\" state.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def storeToEntry(self, xStorage: XStorage_8e460a32, sEntName: str, aMediaArgs: typing.Tuple[PropertyValue_c9610c73, ...], aObjectArgs: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        lets the object store itself to an entry in destination storage, the own persistence entry is not changed.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XEmbedPersist']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoEnumMeta
    class DDELinkMode(metaclass=UnoEnumMeta, type_name="com.sun.star.sheet.DDELinkMode", name_space="com.sun.star.sheet"):
        """Dynamically created class that represents ``com.sun.star.sheet.DDELinkMode`` Enum. Class loosely mimics Enum"""
        pass
else:
    from ...lo.sheet.dde_link_mode import DDELinkMode as DDELinkMode

__all__ = ["DDELinkMode"]



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_configuration import XConfiguration as XConfiguration_8f0511a0

class XConfigurationChangeRequest(ABC):
    """
    A single explicit request for a configuration change.
    
    The requested change is committed to a configuration only when the execute() method is called. Configuration change requests are executed asynchronously. This is done to avoid reentrance problems with objects that are registered as XConfigurationChangeListener and at the same time make configuration change requests. When the requests were executed synchronously then the listeners would be notified of the changes while their request call has not yet returned.
    
    This interface is typically used internally by the XConfigurationController

    See Also:
        `API XConfigurationChangeRequest <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationChangeRequest.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XConfigurationChangeRequest'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XConfigurationChangeRequest'

    @abstractmethod
    def execute(self, xConfiguration: XConfiguration_8f0511a0) -> None:
        """
        Commit the configuration change request represented by the called object to the given configuration.
        """
        ...

__all__ = ['XConfigurationChangeRequest']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from abc import abstractproperty
from .chart_axis_x_supplier import ChartAxisXSupplier as ChartAxisXSupplier_a950e4d
from .chart_statistics import ChartStatistics as ChartStatistics_e2190d37
from .chart_two_axis_y_supplier import ChartTwoAxisYSupplier as ChartTwoAxisYSupplier_380d0f88
from .diagram import Diagram as Diagram_844409cf
from .x_statistic_display import XStatisticDisplay as XStatisticDisplay_fdf40e00

class StockDiagram(ChartAxisXSupplier_a950e4d, ChartStatistics_e2190d37, ChartTwoAxisYSupplier_380d0f88, Diagram_844409cf, XStatisticDisplay_fdf40e00):
    """
    Service Class

    specifies a diagram which can be used for presenting stock quotes.
    
    Note that the data must have a specific structure for stock diagrams. Let us assume that data is interpreted, such that series are taken from columns (see property Diagram.DataRowSource). Then you need tables of the following structures for different types:
    
    StockDiagram.Volume is FALSEStockDiagram.UpDown is FALSE
    
    StockDiagram.Volume is TRUEStockDiagram.UpDown is FALSE
    
    StockDiagram.Volume is FALSEStockDiagram.UpDown is TRUE
    
    StockDiagram.Volume is TRUEStockDiagram.UpDown is TRUE

    See Also:
        `API StockDiagram <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1StockDiagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.StockDiagram'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def UpDown(self) -> bool:
        """
        indicates if a stock chart contains data representing the value of stocks on the opening and closing date.
        
        The difference will be indicated by bars. The color of the bar will be significant for positive or negative differences between open and closed data.
        
        If this property is FALSE, the values of the first series (or second if StockDiagram.Volume is TRUE) of the chart data are interpreted as the day's lowest value. The next series is interpreted as the day's highest value, and the last series is interpreted as the closing value.
        
        If this property is set to TRUE, one additional series is needed with the opening value of the stocks. It is assumed as the series before the series with the day's lowest value.
        """
        ...

    @abstractproperty
    def Volume(self) -> bool:
        """
        indicates if a stock chart contains data representing the volume of stocks.
        
        The values of the volume are represented as columns like those of a BarDiagram.
        
        If this property is set to TRUE, the values of the first series of the chart data are interpreted as volume.
        """
        ...


__all__ = ['StockDiagram']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rdf


class URIs(object):
    """
    Const Class

    Constants to specify some well-known URIs.
    
    These constants are for use with URI.createKnown().
    
    **since**
    
        OOo 3.2

    See Also:
        `API URIs <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rdf_1_1URIs.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rdf'
    __ooo_full_ns__: str = 'com.sun.star.rdf.URIs'
    __ooo_type_name__: str = 'const'

    XSD_NCNAME = 1
    """
    http://www.w3.org/2001/XMLSchema-datatypes#NCName
    """
    XSD_STRING = 2
    """
    http://www.w3.org/2001/XMLSchema-datatypes#string
    """
    XSD_NORMALIZEDSTRING = 3
    """
    http://www.w3.org/2001/XMLSchema-datatypes#normalizedString
    """
    XSD_BOOLEAN = 4
    """
    http://www.w3.org/2001/XMLSchema-datatypes#boolean
    """
    XSD_DECIMAL = 5
    """
    http://www.w3.org/2001/XMLSchema-datatypes#decimal
    """
    XSD_FLOAT = 6
    """
    http://www.w3.org/2001/XMLSchema-datatypes#float
    """
    XSD_DOUBLE = 7
    """
    http://www.w3.org/2001/XMLSchema-datatypes#double
    """
    XSD_INTEGER = 8
    """
    http://www.w3.org/2001/XMLSchema-datatypes#integer
    """
    XSD_NONNEGATIVEINTEGER = 9
    """
    http://www.w3.org/2001/XMLSchema-datatypes#nonNegativeInteger
    """
    XSD_POSITIVEINTEGER = 10
    """
    http://www.w3.org/2001/XMLSchema-datatypes#positiveInteger
    """
    XSD_NONPOSITIVEINTEGER = 11
    """
    http://www.w3.org/2001/XMLSchema-datatypes#nonPositiveInteger
    """
    XSD_NEGATIVEINTEGER = 12
    """
    http://www.w3.org/2001/XMLSchema-datatypes#negativeInteger
    """
    XSD_LONG = 13
    """
    http://www.w3.org/2001/XMLSchema-datatypes#long
    """
    XSD_INT = 14
    """
    http://www.w3.org/2001/XMLSchema-datatypes#int
    """
    XSD_SHORT = 15
    """
    http://www.w3.org/2001/XMLSchema-datatypes#short
    """
    XSD_BYTE = 16
    """
    http://www.w3.org/2001/XMLSchema-datatypes#byte
    """
    XSD_UNSIGNEDLONG = 17
    """
    http://www.w3.org/2001/XMLSchema-datatypes#unsignedLong
    """
    XSD_UNSIGNEDINT = 18
    """
    http://www.w3.org/2001/XMLSchema-datatypes#unsignedInt
    """
    XSD_UNSIGNEDSHORT = 19
    """
    http://www.w3.org/2001/XMLSchema-datatypes#unsignedShort
    """
    XSD_UNSIGNEDBYTE = 20
    """
    http://www.w3.org/2001/XMLSchema-datatypes#unsignedByte
    """
    XSD_HEXBINARY = 21
    """
    http://www.w3.org/2001/XMLSchema-datatypes#hexBinary
    """
    XSD_BASE64BINARY = 22
    """
    http://www.w3.org/2001/XMLSchema-datatypes#base64Binary
    """
    XSD_DATETIME = 23
    """
    http://www.w3.org/2001/XMLSchema-datatypes#dateTime
    """
    XSD_TIME = 24
    """
    http://www.w3.org/2001/XMLSchema-datatypes#time
    """
    XSD_DATE = 25
    """
    http://www.w3.org/2001/XMLSchema-datatypes#date
    """
    XSD_GYEARMONTH = 26
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gYearMonth
    """
    XSD_GYEAR = 27
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gYear
    """
    XSD_GMONTHDAY = 28
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gMonthDay
    """
    XSD_GDAY = 29
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gDay
    """
    XSD_GMONTH = 30
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gMonth
    """
    XSD_ANYURI = 31
    """
    http://www.w3.org/2001/XMLSchema-datatypes#anyURI
    """
    XSD_TOKEN = 32
    """
    http://www.w3.org/2001/XMLSchema-datatypes#token
    """
    XSD_LANGUAGE = 33
    """
    http://www.w3.org/2001/XMLSchema-datatypes#language
    """
    XSD_NMTOKEN = 34
    """
    http://www.w3.org/2001/XMLSchema-datatypes#NMTOKEN
    """
    XSD_NAME = 35
    """
    http://www.w3.org/2001/XMLSchema-datatypes#Name
    """
    XSD_DURATION = 36
    """
    http://www.w3.org/2001/XMLSchema-datatypes#duration
    """
    XSD_QNAME = 37
    """
    http://www.w3.org/2001/XMLSchema-datatypes#QName
    """
    XSD_NOTATION = 38
    """
    http://www.w3.org/2001/XMLSchema-datatypes#NOTATION
    """
    XSD_NMTOKENS = 39
    """
    http://www.w3.org/2001/XMLSchema-datatypes#NMTOKENS
    """
    XSD_ID = 40
    """
    http://www.w3.org/2001/XMLSchema-datatypes#ID
    """
    XSD_IDREF = 41
    """
    http://www.w3.org/2001/XMLSchema-datatypes#IDREF
    """
    XSD_IDREFS = 42
    """
    http://www.w3.org/2001/XMLSchema-datatypes#IDREFS
    """
    XSD_ENTITY = 43
    """
    http://www.w3.org/2001/XMLSchema-datatypes#ENTITY
    """
    XSD_ENTITIES = 44
    """
    http://www.w3.org/2001/XMLSchema-datatypes#ENTITIES
    """
    RDF_TYPE = 1000
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#type
    """
    RDF_SUBJECT = 1001
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#subject
    """
    RDF_PREDICATE = 1002
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#predicate
    """
    RDF_OBJECT = 1003
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#object
    """
    RDF_PROPERTY = 1004
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Property
    """
    RDF_STATEMENT = 1005
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Statement
    """
    RDF_VALUE = 1006
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#value
    """
    RDF_FIRST = 1007
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#first
    """
    RDF_REST = 1008
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#rest
    """
    RDF_NIL = 1009
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#nil
    """
    RDF_XMLLITERAL = 1010
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral
    """
    RDF_ALT = 1011
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Alt
    """
    RDF_BAG = 1012
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Bag
    """
    RDF_LIST = 1013
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#List
    """
    RDF_SEQ = 1014
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Seq
    """
    RDF_1 = 1015
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#_1
    """
    RDFS_COMMENT = 1100
    """
    http://www.w3.org/2000/01/rdf-schema#comment
    """
    RDFS_LABEL = 1101
    """
    http://www.w3.org/2000/01/rdf-schema#label
    """
    RDFS_DOMAIN = 1102
    """
    http://www.w3.org/2000/01/rdf-schema#domain
    """
    RDFS_RANGE = 1103
    """
    http://www.w3.org/2000/01/rdf-schema#range
    """
    RDFS_SUBCLASSOF = 1104
    """
    http://www.w3.org/2000/01/rdf-schema#subClassOf
    """
    RDFS_LITERAL = 1105
    """
    http://www.w3.org/2000/01/rdf-schema#Literal
    """
    RDFS_MEMBER = 1106
    """
    http://www.w3.org/2000/01/rdf-schema#member
    """
    RDFS_SUBPROPERTYOF = 1107
    """
    http://www.w3.org/2000/01/rdf-schema#subPropertyOf
    """
    RDFS_ISDEFINEDBY = 1108
    """
    http://www.w3.org/2000/01/rdf-schema#isDefinedBy
    """
    RDFS_SEEALSO = 1109
    """
    http://www.w3.org/2000/01/rdf-schema#seeAlso
    """
    RDFS_RESOURCE = 1110
    """
    http://www.w3.org/2000/01/rdf-schema#Resource
    """
    RDFS_CLASS = 1111
    """
    http://www.w3.org/2000/01/rdf-schema#Class
    """
    RDFS_DATATYPE = 1112
    """
    http://www.w3.org/2000/01/rdf-schema#Datatype
    """
    RDFS_CONTAINER = 1113
    """
    http://www.w3.org/2000/01/rdf-schema#Container
    """
    RDFS_CONTAINERMEMBERSHIPPROPERTY = 1114
    """
    http://www.w3.org/2000/01/rdf-schema#ContainerMembershipProperty
    """
    OWL_CLASS = 1200
    """
    http://www.w3.org/2002/07/owl#Class
    """
    OWL_OBJECTPROPERTY = 1201
    """
    http://www.w3.org/2002/07/owl#ObjectProperty
    """
    OWL_DATATYPEPROPERTY = 1202
    """
    http://www.w3.org/2002/07/owl#DatatypeProperty
    """
    OWL_FUNCTIONALPROPERTY = 1203
    """
    http://www.w3.org/2002/07/owl#FunctionalProperty
    """
    OWL_THING = 1204
    """
    http://www.w3.org/2002/07/owl#Thing
    """
    OWL_NOTHING = 1205
    """
    http://www.w3.org/2002/07/owl#Nothing
    """
    OWL_INDIVIDUAL = 1206
    """
    http://www.w3.org/2002/07/owl#Individual
    """
    OWL_EQUIVALENTCLASS = 1207
    """
    http://www.w3.org/2002/07/owl#equivalentClass
    """
    OWL_EQUIVALENTPROPERTY = 1208
    """
    http://www.w3.org/2002/07/owl#equivalentProperty
    """
    OWL_SAMEAS = 1209
    """
    http://www.w3.org/2002/07/owl#sameAs
    """
    OWL_DIFFERENTFROM = 1210
    """
    http://www.w3.org/2002/07/owl#differentFrom
    """
    OWL_ALLDIFFERENT = 1211
    """
    http://www.w3.org/2002/07/owl#AllDifferent
    """
    OWL_DISTINCTMEMBERS = 1212
    """
    http://www.w3.org/2002/07/owl#distinctMembers
    """
    OWL_INVERSEOF = 1213
    """
    http://www.w3.org/2002/07/owl#inverseOf
    """
    OWL_TRANSITIVEPROPERTY = 1214
    """
    http://www.w3.org/2002/07/owl#TransitiveProperty
    """
    OWL_SYMMETRICPROPERTY = 1215
    """
    http://www.w3.org/2002/07/owl#SymmetricProperty
    """
    OWL_INVERSEFUNCTIONALPROPERTY = 1216
    """
    http://www.w3.org/2002/07/owl#InverseFunctionalProperty
    """
    OWL_RESTRICTION = 1217
    """
    http://www.w3.org/2002/07/owl#Restriction
    """
    OWL_ONPROPERTY = 1218
    """
    http://www.w3.org/2002/07/owl#onProperty
    """
    OWL_ALLVALUESFROM = 1219
    """
    http://www.w3.org/2002/07/owl#allValuesFrom
    """
    OWL_SOMEVALUESFROM = 1220
    """
    http://www.w3.org/2002/07/owl#someValuesFrom
    """
    OWL_MINCARDINALITY = 1221
    """
    http://www.w3.org/2002/07/owl#minCardinality
    """
    OWL_MAXCARDINALITY = 1222
    """
    http://www.w3.org/2002/07/owl#maxCardinality
    """
    OWL_CARDINALITY = 1223
    """
    http://www.w3.org/2002/07/owl#cardinality
    """
    OWL_ONTOLOGY = 1224
    """
    http://www.w3.org/2002/07/owl#Ontology
    """
    OWL_IMPORTS = 1225
    """
    http://www.w3.org/2002/07/owl#imports
    """
    OWL_VERSIONINFO = 1226
    """
    http://www.w3.org/2002/07/owl#versionInfo
    """
    OWL_PRIORVERSION = 1227
    """
    http://www.w3.org/2002/07/owl#priorVersion
    """
    OWL_BACKWARDCOMPATIBLEWITH = 1228
    """
    http://www.w3.org/2002/07/owl#backwardCompatibleWith
    """
    OWL_INCOMPATIBLEWITH = 1229
    """
    http://www.w3.org/2002/07/owl#incompatibleWith
    """
    OWL_DEPRECATEDCLASS = 1230
    """
    http://www.w3.org/2002/07/owl#DeprecatedClass
    """
    OWL_DEPRECATEDPROPERTY = 1231
    """
    http://www.w3.org/2002/07/owl#DeprecatedProperty
    """
    OWL_ANNOTATIONPROPERTY = 1232
    """
    http://www.w3.org/2002/07/owl#AnnotationProperty
    """
    OWL_ONTOLOGYPROPERTY = 1233
    """
    http://www.w3.org/2002/07/owl#OntologyProperty
    """
    OWL_ONEOF = 1234
    """
    http://www.w3.org/2002/07/owl#oneOf
    """
    OWL_DATARANGE = 1235
    """
    http://www.w3.org/2002/07/owl#dataRange
    """
    OWL_DISJOINTWITH = 1236
    """
    http://www.w3.org/2002/07/owl#disjointWith
    """
    OWL_UNIONOF = 1237
    """
    http://www.w3.org/2002/07/owl#unionOf
    """
    OWL_COMPLEMENTOF = 1238
    """
    http://www.w3.org/2002/07/owl#complementOf
    """
    OWL_INTERSECTIONOF = 1239
    """
    http://www.w3.org/2002/07/owl#intersectionOf
    """
    OWL_HASVALUE = 1240
    """
    http://www.w3.org/2002/07/owl#hasValue
    """
    PKG_HASPART = 2000
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#hasPart
    """
    PKG_MIMETYPE = 2003
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#mimeType
    """
    PKG_PACKAGE = 2004
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Package
    """
    PKG_ELEMENT = 2005
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Element
    """
    PKG_FILE = 2006
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#File
    """
    PKG_METADATAFILE = 2007
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#MetadataFile
    """
    PKG_DOCUMENT = 2008
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Document
    """
    ODF_PREFIX = 2100
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#prefix
    """
    ODF_SUFFIX = 2101
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#suffix
    """
    ODF_ELEMENT = 2102
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#Element
    """
    ODF_CONTENTFILE = 2103
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#ContentFile
    """
    ODF_STYLESFILE = 2104
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#StylesFile
    """
    LO_EXT_SHADING = 2106
    """
    custom shading color of an annotated text range or metadata field (replacement of the default field shading color)
    
    urn:org:documentfoundation:names:experimental:office:xmlns:loext:1.0odf#shading
    
    **since**
    
        LibreOffice 7.2
    """

__all__ = ['URIs']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uri
from __future__ import annotations
from .x_uri_scheme_parser import XUriSchemeParser as XUriSchemeParser_d3fd0ca2

class UriSchemeParser_vndDOTsunDOTstarDOTscript(XUriSchemeParser_d3fd0ca2):
    """
    Service Class

    parses textual representations of absolute “vnd.sun.star.script” URLs.
    
    The argument scheme of method com.sun.star.uri.XUriSchemeParser.parse() must always be equal to the string \"vnd.sun.star.script\", ignoring case. The objects returned by com.sun.star.uri.XUriSchemeParser.parse() implement com.sun.star.uri.XVndSunStarScriptUrlReference.
    
    This service is not intended to be instantiated directly by client code. Rather, it should be used indirectly through the com.sun.star.uri.UriReferenceFactory service.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UriSchemeParser_vndDOTsunDOTstarDOTscript <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1uri_1_1UriSchemeParser__vndDOTsunDOTstarDOTscript.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uri'
    __ooo_full_ns__: str = 'com.sun.star.uri.UriSchemeParser_vndDOTsunDOTstarDOTscript'
    __ooo_type_name__: str = 'service'


__all__ = ['UriSchemeParser_vndDOTsunDOTstarDOTscript']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class RasterOperation(Enum):
    """
    Enum Class


    See Also:
        `API RasterOperation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt.html#a54da390665a5b42acc81143cd24926fd>`_
    """
    __ooo_ns__: str = "com.sun.star.awt"
    __ooo_full_ns__: str = "com.sun.star.awt.RasterOperation"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.awt.RasterOperation"

    ALLBITS = "ALLBITS"
    """
    All bits which are affected by this operation are set to 1.
    """
    INVERT = "INVERT"
    """
    All bits which are affected by this operation are inverted.
    """
    OVERPAINT = "OVERPAINT"
    """
    sets all pixel as written in the output operation.
    """
    XOR = "XOR"
    """
    uses the pixel written as one and the current pixel as the other operator of an exclusive or-operation.
    """
    ZEROBITS = "ZEROBITS"
    """
    All bits which are affected by this operation are set to 0.
    """

__all__ = ["RasterOperation"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_dialog_provider import XDialogProvider as XDialogProvider_c70f0c47
if typing.TYPE_CHECKING:
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from ..frame.x_model import XModel as XModel_7a6e095c
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..script.x_script_listener import XScriptListener as XScriptListener_f20b0db0

class DialogProvider(XDialogProvider_c70f0c47):
    """
    Service Class

    Specifies a provider for dialogs implementing the com.sun.star.awt.XDialog interface.

    See Also:
        `API DialogProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1DialogProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.DialogProvider'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createWithModel(self, Model: XModel_7a6e095c) -> None:
        """
        """
        ...
    @abstractmethod
    def createWithModelAndScripting(self, Model: XModel_7a6e095c, InStream: XInputStream_98d40ab4, DialogLib: XNameContainer_cb90e47, ScriptListener: XScriptListener_f20b0db0) -> None:
        """
        """
        ...

__all__ = ['DialogProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .authentication_request import AuthenticationRequest as AuthenticationRequest_1b520eeb
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..task.interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7

class URLAuthenticationRequest(AuthenticationRequest_1b520eeb):
    """
    Exception Class

    An error specifying lack of correct authentication data (e.g., to log into an account).
    
    **since**
    
        OOo 3.2

    See Also:
        `API URLAuthenticationRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1URLAuthenticationRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.URLAuthenticationRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.ucb.URLAuthenticationRequest'
    __pyunostruct__: str = 'com.sun.star.ucb.URLAuthenticationRequest'

    typeName: str = 'com.sun.star.ucb.URLAuthenticationRequest'
    """Literal Constant ``com.sun.star.ucb.URLAuthenticationRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Classification: typing.Optional[InteractionClassification_6c4d10e7] = InteractionClassification_6c4d10e7.ERROR, ServerName: typing.Optional[str] = '', Diagnostic: typing.Optional[str] = '', HasRealm: typing.Optional[bool] = False, Realm: typing.Optional[str] = '', HasUserName: typing.Optional[bool] = False, UserName: typing.Optional[str] = '', HasPassword: typing.Optional[bool] = False, Password: typing.Optional[str] = '', HasAccount: typing.Optional[bool] = False, Account: typing.Optional[str] = '', URL: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            ServerName (str, optional): ServerName value.
            Diagnostic (str, optional): Diagnostic value.
            HasRealm (bool, optional): HasRealm value.
            Realm (str, optional): Realm value.
            HasUserName (bool, optional): HasUserName value.
            UserName (str, optional): UserName value.
            HasPassword (bool, optional): HasPassword value.
            Password (str, optional): Password value.
            HasAccount (bool, optional): HasAccount value.
            Account (str, optional): Account value.
            URL (str, optional): URL value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Classification": Classification,
            "ServerName": ServerName,
            "Diagnostic": Diagnostic,
            "HasRealm": HasRealm,
            "Realm": Realm,
            "HasUserName": HasUserName,
            "UserName": UserName,
            "HasPassword": HasPassword,
            "Password": Password,
            "HasAccount": HasAccount,
            "Account": Account,
            "URL": URL,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._url = kwargs["URL"]
        inst_keys = ('URL',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def URL(self) -> str:
        """
        The URL for which authentication is requested.
        """
        return self._url
    
    @URL.setter
    def URL(self, value: str) -> None:
        self._url = value


__all__ = ['URLAuthenticationRequest']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..embed.x_storage import XStorage as XStorage_8e460a32

class XUIConfigurationStorage(XInterface_8f010a43):
    """
    supplies functions to change or get information about the storage of a user interface configuration manager.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUIConfigurationStorage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XUIConfigurationStorage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XUIConfigurationStorage'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XUIConfigurationStorage'

    @abstractmethod
    def hasStorage(self) -> bool:
        """
        checks if an instance has already a storage to load/store its data.
        """
        ...
    @abstractmethod
    def setStorage(self, Storage: XStorage_8e460a32) -> None:
        """
        connects a storage to the user interface configuration manager which is used on subsequent calls of load() and store().
        
        This call needs careful usage as data loss can occur. If the implementation has modified data and a new storage is set the implementation is not allowed to write back the data to the old storage. This must be done explicitly with store(). In general a user interface configuration manager instance is created and initialize by the document model or the module user interface configuration supplier. Normally there is no need to set a storage for a user interface configuration manager. If a copy of the configuration data to another storage should be made, use storeToStorage().
        """
        ...

__all__ = ['XUIConfigurationStorage']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class GraphicLocation(Enum):
    """
    Enum Class


    See Also:
        `API GraphicLocation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style.html#ae71ca73feb713866e85597329dfaec2e>`_
    """
    __ooo_ns__: str = "com.sun.star.style"
    __ooo_full_ns__: str = "com.sun.star.style.GraphicLocation"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.style.GraphicLocation"

    AREA = "AREA"
    """
    The graphic is scaled to fill the whole surrounding area.
    """
    LEFT_BOTTOM = "LEFT_BOTTOM"
    """
    The graphic is located in the bottom left corner.
    """
    LEFT_MIDDLE = "LEFT_MIDDLE"
    """
    The graphic is located in the middle of the left edge.
    """
    LEFT_TOP = "LEFT_TOP"
    """
    The graphic is located in the top left corner.
    """
    MIDDLE_BOTTOM = "MIDDLE_BOTTOM"
    """
    The graphic is located in the middle of the bottom edge.
    """
    MIDDLE_MIDDLE = "MIDDLE_MIDDLE"
    """
    The graphic is located at the center of the surrounding object.
    """
    MIDDLE_TOP = "MIDDLE_TOP"
    """
    The graphic is located in the middle of the top edge.
    """
    NONE = "NONE"
    """
    No column or page break is applied.
    
    This value specifies that a location is not yet assigned.
    """
    RIGHT_BOTTOM = "RIGHT_BOTTOM"
    """
    The graphic is located in the bottom right corner.
    """
    RIGHT_MIDDLE = "RIGHT_MIDDLE"
    """
    The graphic is located in the middle of the right edge.
    """
    RIGHT_TOP = "RIGHT_TOP"
    """
    The graphic is located in the top right corner.
    """
    TILED = "TILED"
    """
    The graphic is repeatedly spread over the surrounding object like tiles.
    """

__all__ = ["GraphicLocation"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class Endianness(metaclass=UnoConstMeta, type_name="com.sun.star.util.Endianness", name_space="com.sun.star.util"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.util.Endianness``"""
        pass

    class EndiannessEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.util.Endianness", name_space="com.sun.star.util"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.util.Endianness`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.util import Endianness as Endianness
    else:
        # keep document generators happy
        from ...lo.util.endianness import Endianness as Endianness

    class EndiannessEnum(IntEnum):
        """
        Enum of Const Class Endianness

        These constants describe the endianness of data structures.
        
        The endianness specifies the order in which the bytes of larger types are laid out in memory.
        
        **since**
        
            OOo 2.0
        """
        LITTLE = Endianness.LITTLE
        """
        Little endian.
        
        The values are stored in little endian format, i.e. the bytes of the long word 0xAABBCCDD are laid out like 0xDD, 0xCC, 0xBB, 0xAA in memory. That is, data of arbitrary machine word lengths always starts with the least significant byte, and ends with the most significant one.
        """
        BIG = Endianness.BIG
        """
        Big endian.
        
        The values are stored in big endian format, i.e. the bytes of the long word 0xAABBCCDD are laid out like 0xAA, 0xBB, 0xCC, 0xDD in memory. That is, data of arbitrary machine word lengths always start with the most significant byte, and ends with the least significant one.
        """

__all__ = ['Endianness', 'EndiannessEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .template_identifier import TemplateIdentifier as TemplateIdentifier_2aaa14b5

class XSchemaHandler(XInterface_8f010a43):
    """
    receives a description of a configuration schema as a sequence of events.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XSchemaHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XSchemaHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.XSchemaHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.XSchemaHandler'

    @abstractmethod
    def addInstance(self, aName: str, aTemplate: TemplateIdentifier_2aaa14b5) -> None:
        """
        receives notification that the current group has a child node that is an instance of a specified template.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def addItemType(self, aItemType: TemplateIdentifier_2aaa14b5) -> None:
        """
        receives notification that the current set can contain items that are instances of a specified template.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def addProperty(self, aName: str, aAttributes: int, aType: object) -> None:
        """
        receives notification that a property is added to the current node.
        
        The property will have a default value of NULL (unless it is SchemaAttribute.REQUIRED).
        
        The value is a combination of SchemaAttribute flags.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def addPropertyWithDefault(self, aName: str, aAttributes: int, aDefaultValue: object) -> None:
        """
        receives notification that a property having a default value is added to the current node.
        
        The value is a combination of SchemaAttribute flags.
        
        The value also determines the type. Therefore the value must not be VOID.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def endComponent(self) -> None:
        """
        receives notification that a component description is complete.
        
        Must match a previous call to startComponent().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def endNode(self) -> None:
        """
        receives notification that a node description is complete.
        
        Must match the last open call to startGroup() or startSet().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def endSchema(self) -> None:
        """
        receives notification that the current schema description is complete.
        
        Must match a previous call to startSchema().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def endTemplate(self) -> None:
        """
        receives notification that a template description is complete.
        
        Must match a previous call to startGroupTemplate() or startSetTemplate().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def importComponent(self, aName: str) -> None:
        """
        receives notification that the schema depends on templates from a different component.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def startComponent(self, aName: str) -> None:
        """
        receives notification that a component description is started.
        
        Subsequent calls describe the schema of the component until a matching call to endComponent() is encountered.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def startGroup(self, aName: str, aAttributes: int) -> None:
        """
        receives notification that a group description is started.
        
        Subsequent calls describe the members and properties of the group until a matching call to endNode() is encountered.
        
        The value is a combination of SchemaAttribute flags.
        
        SchemaAttribute.EXTENSIBLE can be used to describe a group with an extensible set of properties.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def startGroupTemplate(self, aTemplate: TemplateIdentifier_2aaa14b5, aAttributes: int) -> None:
        """
        receives notification that a template description is started for a group.
        
        Subsequent calls describe the members and properties of the template until a matching call to endTemplate() is encountered.
        
        The value is a combination of SchemaAttribute flags.
        
        SchemaAttribute.EXTENSIBLE can be used to describe a template for a node with an extensible set of properties.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def startSchema(self) -> None:
        """
        receives notification that a schema description is started.
        
        The schema description may comprise components templates or both.

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def startSet(self, aName: str, aAttributes: int, aItemType: TemplateIdentifier_2aaa14b5) -> None:
        """
        receives notification that a set description is started.
        
        Subsequent calls describe the item-types and properties of the set until a matching call to endNode() is encountered.
        
        The value is a combination of SchemaAttribute flags.
        
        SchemaAttribute.EXTENSIBLE can be used to describe a set with an extensible set of properties.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def startSetTemplate(self, aTemplate: TemplateIdentifier_2aaa14b5, aAttributes: int, aItemType: TemplateIdentifier_2aaa14b5) -> None:
        """
        receives notification that a template description is started for a set.
        
        Subsequent calls describe the members and properties of the template until a matching call to endTemplate() is encountered.
        
        The value is a combination of SchemaAttribute flags.
        
        SchemaAttribute.EXTENSIBLE can be used to describe a template for a node with an extensible set of properties.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XSchemaHandler']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ConditionOperator2(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.ConditionOperator2", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.ConditionOperator2``"""
        pass

    class ConditionOperator2Enum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.ConditionOperator2", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.ConditionOperator2`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sheet import ConditionOperator2 as ConditionOperator2
    else:
        # keep document generators happy
        from ...lo.sheet.condition_operator2 import ConditionOperator2 as ConditionOperator2

    class ConditionOperator2Enum(IntEnum):
        """
        Enum of Const Class ConditionOperator2

        is used to specify the type of XSheetCondition2.
        """
        NONE = ConditionOperator2.NONE
        """
        no condition is specified.
        """
        EQUAL = ConditionOperator2.EQUAL
        """
        value has to be equal to the specified value.
        """
        NOT_EQUAL = ConditionOperator2.NOT_EQUAL
        """
        the value must not be equal to the specified value.
        """
        GREATER = ConditionOperator2.GREATER
        """
        the value has to be greater than the specified value.
        """
        GREATER_EQUAL = ConditionOperator2.GREATER_EQUAL
        """
        the value has to be greater than or equal to the specified value.
        """
        LESS = ConditionOperator2.LESS
        """
        the value has to be less than the specified value.
        """
        LESS_EQUAL = ConditionOperator2.LESS_EQUAL
        """
        the value has to be less than or equal to the specified value.
        """
        BETWEEN = ConditionOperator2.BETWEEN
        """
        the value has to be between the two specified values.
        """
        NOT_BETWEEN = ConditionOperator2.NOT_BETWEEN
        """
        the value has to be outside of the two specified values.
        """
        FORMULA = ConditionOperator2.FORMULA
        """
        the specified formula has to give a non-zero result.
        """
        DUPLICATE = ConditionOperator2.DUPLICATE
        """
        Conditionally format duplicate values.
        """
        NOT_DUPLICATE = ConditionOperator2.NOT_DUPLICATE
        """
        Conditionally format non-duplicate values.
        """

__all__ = ['ConditionOperator2', 'ConditionOperator2Enum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class UIElementType(metaclass=UnoConstMeta, type_name="com.sun.star.ui.UIElementType", name_space="com.sun.star.ui"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ui.UIElementType``"""
        pass

    class UIElementTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ui.UIElementType", name_space="com.sun.star.ui"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ui.UIElementType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ui import UIElementType as UIElementType
    else:
        # keep document generators happy
        from ...lo.ui.ui_element_type import UIElementType as UIElementType

    class UIElementTypeEnum(IntEnum):
        """
        Enum of Const Class UIElementType

        determine the type of a user interface element which is controlled by a layout manager.
        
        **since**
        
            OOo 2.0
        """
        UNKNOWN = UIElementType.UNKNOWN
        """
        unknown user interface element type, which can be used as a wildcard to specify all types.
        """
        MENUBAR = UIElementType.MENUBAR
        """
        specifies a menu bar.
        """
        POPUPMENU = UIElementType.POPUPMENU
        """
        specifies a pop-up menu.
        """
        TOOLBAR = UIElementType.TOOLBAR
        """
        specifies a toolbar.
        """
        STATUSBAR = UIElementType.STATUSBAR
        """
        specifies a statusbar.
        """
        FLOATINGWINDOW = UIElementType.FLOATINGWINDOW
        """
        specifies a floating window, which can also be docked.
        """
        PROGRESSBAR = UIElementType.PROGRESSBAR
        """
        specifies a floating window, which can also be docked.
        """
        TOOLPANEL = UIElementType.TOOLPANEL
        """
        specifies a tool panel
        """
        DOCKINGWINDOW = UIElementType.DOCKINGWINDOW
        """
        specifies a window that can be docked.
        """
        COUNT = UIElementType.COUNT
        """
        specifies the number of constants.
        """

__all__ = ['UIElementType', 'UIElementTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class NativeNumberMode(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.NativeNumberMode", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.NativeNumberMode``"""
        pass

    class NativeNumberModeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.NativeNumberMode", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.NativeNumberMode`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import NativeNumberMode as NativeNumberMode
    else:
        # keep document generators happy
        from ...lo.i18n.native_number_mode import NativeNumberMode as NativeNumberMode

    class NativeNumberModeEnum(IntEnum):
        """
        Enum of Const Class NativeNumberMode

        Constants to use with XExtendedCalendar.getDisplayString() and the XNativeNumberSupplier methods.
        
        The constants have different meanings if used with different locales. However, NATNUM1 always tries to convert to a string matching the native number mode of the corresponding locale.
        
        Where available, the corresponding Microsoft Excel (tm) DBNum number format code modifier is listed.
        
        Modifiers supported by XExtendedCalendar.getDisplayString() are marked with CAL: for the specific language and the corresponding DBNum modifier and the NatNum values used for Y/M/D are listed
        
        **since**
        
            OOo 1.1.2
        """
        NATNUM0 = NativeNumberMode.NATNUM0
        """
        Transliteration to ASCII Arabic digits.
        
        Try to convert any native number string to ASCII. If already ASCII it remains ASCII.
        """
        NATNUM1 = NativeNumberMode.NATNUM1
        """
        Transliteration in Chinese: Chinese lower case characters; CAL: 1/7/7 [DBNum1] Japanese: short Kanji characters [DBNum1]; CAL: 1/4/4 [DBNum1] Korean: Korean lower case characters [DBNum1]; CAL: 1/7/7 [DBNum1] Hebrew: Hebrew characters Arabic: Arabic-Indic characters Thai: Thai characters Hindi: Indic-Devanagari characters Odia: Odia (Oriya) charactersMarathi: Indic-Devanagari charactersBengali: Bengali charactersPunjabi: Punjabi (Gurmukhi) charactersGujarati: Gujarati charactersTamil: Tamil charactersTelugu: Telugu charactersKannada: Kannada charactersMalayalam: Malayalam charactersLao: Lao charactersTibetan: Tibetan charactersBurmese: Burmese (Myanmar) charactersKhmer: Khmer (Cambodian) charactersMongolian: Mongolian charactersNepali: Indic-Devanagari charactersDzongkha: Tibetan charactersFarsi: East Arabic-Indic charactersChurch Slavic: Cyrillic characters.
        """
        NATNUM2 = NativeNumberMode.NATNUM2
        """
        Transliteration in Chinese: Chinese upper case characters; CAL: 2/8/8 [DBNum2] Japanese: traditional Kanji characters; CAL: 2/5/5 [DBNum2] Korean: Korean upper case characters [DBNum2]; CAL: 2/8/8 [DBNum2] Hebrew: Hebrew numbering.
        """
        NATNUM3 = NativeNumberMode.NATNUM3
        """
        Transliteration in Chinese: fullwidth Arabic digits; CAL: 3/3/3 [DBNum3] Japanese: fullwidth Arabic digits; CAL: 3/3/3 [DBNum3] Korean: fullwidth Arabic digits [DBNum3]; CAL: 3/3/3 [DBNum3].
        """
        NATNUM4 = NativeNumberMode.NATNUM4
        """
        Transliteration in Chinese: lower case text [DBNum1] Japanese: modern long Kanji text [DBNum2] Korean: formal lower case text.
        """
        NATNUM5 = NativeNumberMode.NATNUM5
        """
        Transliteration in Chinese: Chinese upper case text [DBNum2] Japanese: traditional long Kanji text [DBNum3] Korean: formal upper case text.
        """
        NATNUM6 = NativeNumberMode.NATNUM6
        """
        Transliteration in Chinese: fullwidth text [DBNum3] Japanese: fullwidth text Korean: fullwidth text.
        """
        NATNUM7 = NativeNumberMode.NATNUM7
        """
        Transliteration in Chinese: short lower case text Japanese: modern short Kanji text Korean: informal lower case text.
        """
        NATNUM8 = NativeNumberMode.NATNUM8
        """
        Transliteration in Chinese: short upper case text Japanese: traditional short Kanji text [DBNum4] Korean: informal upper case text.
        """
        NATNUM9 = NativeNumberMode.NATNUM9
        """
        Transliteration in Korean: Hangul characters.
        """
        NATNUM10 = NativeNumberMode.NATNUM10
        """
        Transliteration in Korean: formal Hangul text [DBNum4]; CAL: 9/11/11 [DBNum4].
        """
        NATNUM11 = NativeNumberMode.NATNUM11
        """
        Transliteration in Korean: informal Hangul text.
        """
        NATNUM12 = NativeNumberMode.NATNUM12
        """
        Transliteration to cardinal number names (one, two, three, ...), ordinal number names (first, second, third, ...), ordinal indicators (1st, 2nd, 3rd, ...), etc.
        
        Uses NatNum params string
        """

__all__ = ['NativeNumberMode', 'NativeNumberModeEnum']
